Changelog
=========

1.0.0 (2018/12/11)
------------------
- Python 3 compatiblity
- Plone 5.2/Zope 4 compatiblity
- reduced functionality to IPPServer connectivity only

0.4.5  (2017-10-02)
-------------------
- fixes for Plone 5.1

0.4.4  (2017-02-19)
-------------------
- support for fetching resources by URL

0.4.3  (2017-02-18)
-------------------
- limited support for Dexterity images

0.4.2  (2017-02-16)
-------------------
- support for supplementary_css parameter

0.4.1  (2017-02-13)
-------------------
- enabled cert validation by default

0.4.0  (2016-12-04)
-------------------
- compatibility with Plone 5.0/5.1 and Archetypes content


0.3.9 (2016-04-26)
------------------
- wording

0.3.8 (2015-11-19)
------------------
- CSS for Plone 5 control panel included

0.3.7 (2015-11-18)
------------------
- Documentation updated

0.3.5 (2015-11-18)
------------------
- Plone 5 compatibility

0.3.4. (2015-04-23)
-------------------
- merged https://bitbucket.org/ajung/pp.client-plone/pull-request/4/

0.3.3 (2015-02-18)
------------------
- added "Test connection" button to P&P control panel

0.3.2 (2015-02-05)
------------------
- fixed issue with suffix of download filename

0.3.1 (2015-01-26)
------------------
- username/password are no longer mandatory

0.3.0 (2015-01-19)
------------------
- better integration with XML Director project
- controlpanel for PP server settings
- webservice settings are now being persisted
  per Plone instance instead of per Zope installation
- updated documentation

0.2.5 (2014-11-17)
------------------
- minor fix

0.2.3 (24-03-2014)
------------------
- typo in fonts.css fixed

0.2.2 (24-10-2013)
------------------
- reorganized directory layout
- fixed issues with nested resource directories
  in copyResources()  

0.2.1 (06-10-2013)
------------------
- added browser layer

0.2.0 (03-10-2013)
------------------
- updated documentation 

0.1.9 (30-09-2013)
------------------

- support for new-style collections (Plone 4.3+)
  and images

0.1.8 (30-09-2013)
------------------

- some fixes for folder aggregation

0.1.7 (19-09-2013)
------------------

- images used from within a PDF template file directly
  inside a resource should be marked with
  <img internal-image="true" src="..." />

0.1.6 (17-09-2013)
------------------

- merged https://bitbucket.org/ajung/pp.client-plone/pull-request/2/fixed-umlaut-problem-of-images-and/diff

0.1.5 (21-08-2013)
------------------

- merged https://bitbucket.org/ajung/pp.client-plone/pull-request/1/add-missing-transformer-import-in/diff

0.1.5 (21-08-2013)
------------------

- merged https://bitbucket.org/ajung/pp.client-plone/pull-request/1/add-missing-transformer-import-in/diff

0.1.4 (12-07-2013)
-------------------

- major style and fonts cleanup

0.1.3 (11-07-2013)
-------------------

- various fixes
- Plone 4.0 - 4.2 compatibility

0.1.0 (11-07-2013)
-------------------

- initial release
